@@ -3,21 +3,21 @@ use utf8;
 use strict;
 use warnings FATAL => 'all';
 
-use Muldis::Rosetta::Interface 0.013001;
+use Muldis::Rosetta::Interface 0.013003;
 
-#use Muldis::Rosetta::Engine::Example::Value 0.000000;
-#use Muldis::Rosetta::Engine::Example::Routines 0.000000;
-#use Muldis::Rosetta::Engine::Example::Storage 0.000000;
-#use Muldis::Rosetta::Engine::Example::Runtime 0.000000;
-#use Muldis::Rosetta::Engine::Example::Util 0.000000;
-#use Muldis::Rosetta::Engine::Example::PlainText 0.000000;
-#use Muldis::Rosetta::Engine::Example::HostedData 0.000000;
+#use Muldis::Rosetta::Engine::Example::Value 0.013003;
+#use Muldis::Rosetta::Engine::Example::Routines 0.013003;
+#use Muldis::Rosetta::Engine::Example::Storage 0.013003;
+#use Muldis::Rosetta::Engine::Example::Runtime 0.013003;
+#use Muldis::Rosetta::Engine::Example::Util 0.013003;
+#use Muldis::Rosetta::Engine::Example::PlainText 0.013003;
+#use Muldis::Rosetta::Engine::Example::HostedData 0.013003;
 
 ###########################################################################
 ###########################################################################
 
 { package Muldis::Rosetta::Engine::Example; # module
-    use version 0.74; our $VERSION = qv('0.13.2');
+    use version 0.74; our $VERSION = qv('0.13.3');
     # Note: This given version applies to all of this file's packages.
 
     use namespace::clean;
@@ -37,7 +37,7 @@ sub new_machine {
 
 { package Muldis::Rosetta::Engine::Example::Public::Machine; # class
 
-    use MooseX::Singleton 0.14;
+    use MooseX::Singleton 0.17;
 
     use namespace::clean -except => 'meta';
 
@@ -71,7 +71,7 @@ sub new_process {
 
 { package Muldis::Rosetta::Engine::Example::Public::Process; # class
 
-    use Moose 0.68;
+    use Moose 0.79;
 
     use namespace::clean -except => 'meta';
 
@@ -242,7 +242,7 @@ sub proc_invo {
 
 { package Muldis::Rosetta::Engine::Example::Public::Value; # class
 
-    use Moose 0.68;
+    use Moose 0.79;
 
     use namespace::clean -except => 'meta';
 
@@ -348,7 +348,7 @@ Self-contained reference implementation of a Muldis Rosetta Engine
 
 =head1 VERSION
 
-This document describes Muldis::Rosetta::Engine::Example version 0.13.2 for
+This document describes Muldis::Rosetta::Engine::Example version 0.13.3 for
 Perl 5.
 
 It also describes the same-number versions for Perl 5 of
@@ -368,7 +368,7 @@ implementation of Muldis Rosetta.  It is included in the Muldis Rosetta
 core distribution to allow the core to be completely testable on its own.
 
 Example is coded intentionally in a simple fashion so that it is easy to
-maintain and and easy for developers to study.  As a result, while it
+maintain and easy for developers to study.  As a result, while it
 performs correctly and reliably, it also performs quite slowly; you should
 only use Example for testing, development, and study; you should not use it
 in production.  (See the L<Muldis::Rosetta::SeeAlso> file for a list of
@@ -472,18 +472,18 @@ Example written in any of the following:
 
 =item B<Tiny Plain Text Muldis D>
 
-See L<Muldis::D::Dialect::PTMD_Tiny> for details.
+See L<Muldis::D::Dialect::PTMD_STD> for details.
 
 The language name is specified as a Perl character string whose value is
-C<Muldis_D:'http://muldis.com':'0.59.1':PTMD_Tiny>.  No other version
+C<Muldis_D:"http://muldis.com":"0.75.0":PTMD_STD>.  No other version
 numbers are currently supported.
 
 =item B<Tiny Perl Hosted Data Muldis D>
 
-See L<Muldis::D::Dialect::HDMD_Perl5_Tiny> for details.
+See L<Muldis::D::Dialect::HDMD_Perl5_STD> for details.
 
 The language name is specified either as a Perl array whose value is C<[
-'Muldis_D', 'http://muldis.com', '0.59.1', 'HDMD_Perl5_Tiny' ]>.  No other
+'Muldis_D', 'http://muldis.com', '0.75.0', 'HDMD_Perl5_STD' ]>.  No other
 version numbers are currently supported.
 
 =back
@@ -511,12 +511,13 @@ installation by users of earlier Perl versions:
 L<version-ver(0.74..*)|version>.
 
 It also requires these Perl 5 packages that are on CPAN:
-L<namespace::clean-ver(0.09..*)|namespace::clean>,
-L<Moose-ver(0.68..*)|Moose>, L<Moose::Role-ver(0.68..*)|Moose::Role>,
-L<MooseX::Singleton-ver(0.14..*)|MooseX::Singleton>.
+L<namespace::clean-ver(0.11..*)|namespace::clean>,
+L<Moose-ver(0.79..*)|Moose>, L<Moose::Role-ver(0.79..*)|Moose::Role>,
+L<MooseX::Singleton-ver(0.17..*)|MooseX::Singleton>.
 
-It also requires these Perl 5 classes that are in the current distribution:
-L<Muldis::Rosetta::Interface-ver(0.13.2..*)|Muldis::Rosetta::Interface>.
+It also requires these Perl 5 packages that are in the current
+distribution:
+L<Muldis::Rosetta::Interface-ver(0.13.3..*)|Muldis::Rosetta::Interface>.
 
 =head1 INCOMPATIBILITIES
 
